<?php

namespace Drupal\trackmyadmin\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\trackmyadmin\Utility\QueryHelper;
use Drupal\Component\Utility\Xss;

/**
 * Reports Controller.
 */
class Reports extends ControllerBase {

  /**
   * The replica database connection.
   *
   * @var \Drupal\Database
   */
  protected $connection;

  /**
   * The QueryHelper Object.
   *
   * @var Drupal\trackmyadmin\Utility\QueryHelper
   */
  protected $query;

  /**
   * Constructs the Reports Object.
   */
  public function __construct() {
    $this->connection = \Drupal::database();
    $this->query = new QueryHelper($this->connection);
  }

  /**
   * Returns a render-able array for the Dashboard page.
   */
  public function dashboard() {
    $data = $this->query->fetchValues('content_config');
    $data['base_path'] = \Drupal::request()->getSchemeAndHttpHost();

    return [
      // Your theme hook name.
      '#theme' => 'trackmyadmin_reports_theme',
      // Your variables.
      '#data' => $data,
    ];
  }

  /**
   * Returns a render-able array for the Name Report page.
   *
   * @param string $name
   *   The Identifier Name.
   */
  public function name($name) {
    $data = $this->query->fetchValues('name', ['data' => Xss::filter($name)]);
    $data['base_path'] = \Drupal::request()->getSchemeAndHttpHost();
    $data['current_data'] = 'name';
    $data['data_item'] = Xss::filter($name);

    return [
      // Your theme hook name.
      '#theme' => 'trackmyadmin_reports_data_theme',
      // Your variables.
      '#data' => $data,
    ];
  }

  /**
   * Returns a render-able array for the User Report page.
   *
   * @param string $user
   *   The Identifier User.
   */
  public function user($user) {
    $user_details = user_load_by_name(Xss::filter($user));
    $data = $this->query->fetchValues('uid', ['data' => $user_details->id()]);
    $data['base_path'] = \Drupal::request()->getSchemeAndHttpHost();
    $data['current_data'] = 'user';
    $data['data_item'] = Xss::filter($user);

    return [
      // Your theme hook name.
      '#theme' => 'trackmyadmin_reports_data_theme',
      // Your variables.
      '#data' => $data,
    ];
  }

  /**
   * Returns a render-able array for the Team Report page.
   *
   * @param string $team
   *   The Identifier Team.
   */
  public function team($team) {
    $data = $this->query->fetchValues('team', ['data' => Xss::filter($team)]);
    $data['base_path'] = \Drupal::request()->getSchemeAndHttpHost();
    $data['current_data'] = 'team';
    $data['data_item'] = Xss::filter($team);

    return [
      // Your theme hook name.
      '#theme' => 'trackmyadmin_reports_data_theme',
      // Your variables.
      '#data' => $data,
    ];
  }

  /**
   * Returns a render-able array for the Content Report page.
   */
  public function tmacontent() {
    $data = $this->query->fetchValues('content');
    $data['base_path'] = \Drupal::request()->getSchemeAndHttpHost();
    $data['current_data'] = 'Content';

    return [
      // Your theme hook name.
      '#theme' => 'trackmyadmin_reports_data_view_theme',
      // Your variables.
      '#data' => $data,
    ];
  }

  /**
   * Returns a render-able array for the Config Report page.
   */
  public function tmaconfig() {
    $data = $this->query->fetchValues('config');
    $data['base_path'] = \Drupal::request()->getSchemeAndHttpHost();
    $data['current_data'] = 'Config';

    return [
      // Your theme hook name.
      '#theme' => 'trackmyadmin_reports_data_view_theme',
      // Your variables.
      '#data' => $data,
    ];
  }

}
