<?php

namespace Drupal\trackmyadmin\EventSubscriber;

use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class Subscriber.
 */
class Subscriber implements EventSubscriberInterface {

  /**
   * This is initiated only when KernelEvents::REQUEST.
   *
   * @see Symfony\Component\HttpKernel\KernelEvents
   */
  public function performRedirection(GetResponseEvent $event) {
    $trackmyadmin_form_path = '/trackmyadmin/capture_details';
    $current_path = \Drupal::service('path.current')->getPath();
    $current_user = \Drupal::currentUser();
    $request = \Drupal::request();
    $roles = $current_user->getRoles();
    $session = $request->getSession();
    $tma_user_key = $session->get('tma_user_key');
    // Let us force the administrative user to provide the details in order to proceed any further.
    if (!isset($tma_user_key) && $current_path != $trackmyadmin_form_path && in_array('administrator', $roles)) {
      $event->setResponse(new RedirectResponse($trackmyadmin_form_path));
    }
    // Let us avoid the situation where the users provide the details more than once.
    elseif (isset($tma_user_key) && is_numeric($tma_user_key) && $current_path == $trackmyadmin_form_path && in_array('administrator', $roles)) {
      $event->setResponse(new RedirectResponse('/admin'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::REQUEST][] = ['performRedirection', 20];
    return $events;
  }

}
