<?php

namespace Drupal\trackmyadmin\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\trackmyadmin\Utility\QueryHelper;

/**
 * Class CaptureDetailsForm.
 */
class CaptureDetailsForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tma_capturedetails_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $uname = \Drupal::currentUser()->getAccountName();
    $form['tma_name'] = [
      '#type' => 'textfield',
      '#size' => '60',
      '#placeholder' => 'Enter your Identity other than the "' . $uname . '" username',
      '#title' => $this->t('Your Name'),
      '#required' => TRUE,
      '#weight' => 1,
    ];
    $form['tma_team'] = [
      '#type' => 'select',
      '#title' => $this->t('Your Team'),
      '#options' => [
        'build' => $this->t('Build/Development'),
        'support' => $this->t('Support/Maintenance'),
        'business' => $this->t('Business'),
        'other' => $this->t('Other'),
      ],
      '#empty_option' => $this->t('- Select -'),
      '#weight' => 2,
    ];
    $form['tma_team_other'] = [
      '#type' => 'textfield',
      '#size' => '60',
      '#placeholder' => $this->t('Enter your Team Name'),
      '#weight' => 3,
      '#states' => [
        // Show this textfield only if the above select field 'other' is selected.
        'visible' => [
          ':input[name="tma_team"]' => ['value' => 'other'],
        ],
      ],
    ];
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Proceed'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $tma_name = $form_state->getValue('tma_name');
    $tma_team = $form_state->getValue('tma_team');
    $tma_team_other = $form_state->getValue('tma_team_other');
    // Let us restrict the users to avoid inputting strings 'admin', 'super', 'site'.
    if (preg_match('/admin/', $tma_name) || preg_match('/super/', $tma_name) || preg_match('/site/', $tma_name)) {
      $form_state->setErrorByName('tma_name', $this->t('Please avoid generic names such as admin etc'));
    }
    // Check whether either of the fields are inputted or not.
    if (empty($tma_team) && empty($tma_team_other)) {
      $form_state->setErrorByName('tma_team', $this->t('Please select a team'));
    }
    if (!empty($tma_team) && $tma_team == 'other' && empty($tma_team_other)) {
      $form_state->setErrorByName('tma_team_other', $this->t('Please input a team'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $connection = \Drupal::database();
    $tma_name = $form_state->getValue('tma_name');
    $tma_team = $form_state->getValue('tma_team');
    $tma_team_other = $form_state->getValue('tma_team_other');
    $uid = \Drupal::currentUser()->id();
    $location = NULL;
    $ip_address = \Drupal::request()->getClientIp();
    // Fetch the location details from the external source. Make sure the limit of 120 requests per minute.
    $fetched_address = unserialize(file_get_contents('http://www.geoplugin.net/php.gp?ip=' . $ip_address));
    if (isset($fetched_address['geoplugin_status']) && ($fetched_address['geoplugin_status'] >= 200 && $fetched_address['geoplugin_status'] <= 299)) {
      if ($fetched_address['geoplugin_city']) {
        $location = $fetched_address['geoplugin_city'] . ', ';
      }
      if ($fetched_address['geoplugin_regionName']) {
        $location = $fetched_address['geoplugin_regionName'] . ', ';
      }
      if ($fetched_address['geoplugin_countryName']) {
        $location = $fetched_address['geoplugin_countryName'];
      }
    }
    if (!empty($tma_team) && $tma_team == 'other' && !empty($tma_team_other)) {
      $tma_team = $form_state->getValue('tma_team_other');
    }
    $values = [
      'ip' => $ip_address,
      'location' => $location,
      'name' => $tma_name,
      'team' => $tma_team,
      'uid' => $uid,
      'date' => \Drupal::time()->getCurrentTime()
    ];
    // Initiate our Query Helper.
    $query = new QueryHelper($connection);
    $user_key = $query->insertValues('trackmyadmin_users', $values);
    $request = \Drupal::request();
    $session = $request->getSession();
    $session->set('tma_user_key', $user_key);
    $response = new RedirectResponse('/admin');
    $response->send();
  }

}
